<template>
  <div class="fa-card-a aui-card--fill" shadow="never">
    <div class="mod-sys__tenant}">
      <zt-table-wraper v-slot="{ table }" delete-url="/sys/tenant" query-url="/sys/tenant/page">
            <el-form :inline="true" :model="dataForm" @keyup.enter.native="table.query()">
              <el-form-item style="margin-top: 2px;margin-left: 10px">
                <el-input v-model="dataForm.name" :placeholder="$t('tenant.inputName')" clearable></el-input>
              </el-form-item>
              <el-form-item>
                <el-input v-model="dataForm.code" :placeholder="$t('tenant.inputCode')" clearable></el-input>
              </el-form-item>
              <el-form-item>
                <zt-button class="admin-query-button" type="query" @click="table.query()"/>
                <zt-button perm="sys:tenant" type="add" @click="table.editHandle()"/>
                <zt-button perm="sys:tenant:delete" type="delete" @click="table.deleteHandle()"/>
              </el-form-item>
            </el-form>
            <el-table v-loading="table.dataLoading" :data="table.dataList" border
                      v-adaptive="{bottomOffset:50}"
                      @selection-change="table.selectionChangeHandle">
              <el-table-column align="center" type="selection" width="50"></el-table-column>
              <el-table-column :label="$t('tenant.name')" prop="name"></el-table-column>
              <el-table-column :label="$t('tenant.code')" prop="code"></el-table-column>
              <el-table-column :label="$t('tenant.gmtBegin')" prop="gmtBegin"></el-table-column>
              <el-table-column :label="$t('tenant.gmtEnd')" prop="gmtEnd"></el-table-column>
              <zt-table-column-dict :label="$t('tenant.status')" dict="common_status" prop="status"/>
              <el-table-column :label="$t('tenant.adminMobile')" prop="adminMobile"></el-table-column>
              <zt-table-column-handle :table="table" delete-perm="sys:tenant:delete" edit-perm="sys:tenant:update"
                                      width="200">
                <template v-slot="{ row }">
                  <zt-table-button @click="setTenantMenu(row.id)">{{ $t('tenant.menuRight') }}</zt-table-button>
                </template>
              </zt-table-column-handle>
            </el-table>
        <!-- 弹窗, 新增 / 修改 -->
        <add-or-update @refreshDataList="table.query"/>
        <tenant-menu ref="tenantMenu"/>
      </zt-table-wraper>
    </div>
  </div>
</template>

<script>
import AddOrUpdate from './tenant-add-or-update'
import TenantMenu from './tenant-menu'

export default {
  data() {
    return {
      dataForm: {
        id: ''
      }
    }
  },
  methods: {
    setTenantMenu(tenantId) {
      this.$refs['tenantMenu'].$refs['dialog'].init(tenantId)
    }
  },
  components: {
    AddOrUpdate,
    TenantMenu
  }
}
</script>
